sibling_bin

Function sibling_bin 

pub fn sibling_bin(name: &str) -> Result<PathBuf>
Finds a sibling binary next to the current executable.

Errors

Returns SpikeError::Io if the current executable cannot be determined. Returns SpikeError::Oniro if the executable has no parent directory or if the requested sibling binary cannot be found.